@@ -15,7 +15,7 @@ use strict;
 use vars qw($VERSION);
 use 5.004;
 
-$VERSION = "0.17009"; 
+$VERSION = "0.17015"; 
 
 use overload (
 	'""'	   =>	'stringify',
@@ -140,11 +140,6 @@ sub associate {
     return;
 }
 
-=head2 Error->new()
-
-See the Error::Simple documentation.
-
-=cut
 
 sub new {
     my $self = shift;
@@ -264,12 +259,6 @@ package Error::Simple;
 
 @Error::Simple::ISA = qw(Error);
 
-=head2 Error->new()
-
-See the Error::Simple documentation.
-
-=cut
-
 sub new {
     my $self  = shift;
     my $text  = "" . shift;
@@ -328,7 +317,7 @@ sub run_clauses ($$$\@) {
 		my $pkg = $catch->[$i];
 		unless(defined $pkg) {
 		    #except
-		    splice(@$catch,$i,2,$catch->[$i+1]->());
+		    splice(@$catch,$i,2,$catch->[$i+1]->($err));
 		    $i -= 2;
 		    next CATCHLOOP;
 		}
@@ -767,6 +756,10 @@ an object blessed into that package as the C<-object> argument.
 
 =over 4
 
+=item Error->new()
+
+See the Error::Simple documentation.
+
 =item throw ( [ ARGS ] )
 
 Create a new C<Error> object and throw an error, which will be caught
@@ -976,6 +969,17 @@ into
 
 =cut
 
+=head1 SEE ALSO
+
+See L<Exception::Class> for a different module providing Object-Oriented
+exception handling, along with a convenient syntax for declaring hierarchies
+for them. It doesn't provide Error's syntactic sugar of C<try { ... }>,
+C<catch { ... }>, etc. which may be a good thing or a bad thing based
+on what you want. (Because Error's syntactic sugar tends to break.)
+
+L<Error::Exception> aims to combine L<Error> and L<Exception::Class>
+"with correct stringification".
+
 =head1 KNOWN BUGS
 
 None, but that does not mean there are not any.
